@@ -60,6 +60,7 @@ from .type_defs import (
     GetCostEstimationResponseTypeDef,
     GetResourceCollectionResponseTypeDef,
     InsightFeedbackTypeDef,
+    ListAnomaliesForInsightFiltersTypeDef,
     ListAnomaliesForInsightResponseTypeDef,
     ListAnomalousLogGroupsResponseTypeDef,
     ListEventsFiltersTypeDef,
@@ -321,7 +322,8 @@ class DevOpsGuruClient(BaseClient):
         StartTimeRange: StartTimeRangeTypeDef = ...,
         MaxResults: int = ...,
         NextToken: str = ...,
-        AccountId: str = ...
+        AccountId: str = ...,
+        Filters: ListAnomaliesForInsightFiltersTypeDef = ...
     ) -> ListAnomaliesForInsightResponseTypeDef:
         """
         Returns a list of the anomalies that belong to an insight that you specify using
