@@ -60,6 +60,7 @@ from .type_defs import (
     DescribeResourceCollectionHealthResponseTypeDef,
     GetCostEstimationResponseTypeDef,
     GetResourceCollectionResponseTypeDef,
+    ListAnomaliesForInsightFiltersTypeDef,
     ListAnomaliesForInsightResponseTypeDef,
     ListAnomalousLogGroupsResponseTypeDef,
     ListEventsFiltersTypeDef,
@@ -191,6 +192,7 @@ class ListAnomaliesForInsightPaginator(Paginator):
         InsightId: str,
         StartTimeRange: StartTimeRangeTypeDef = ...,
         AccountId: str = ...,
+        Filters: ListAnomaliesForInsightFiltersTypeDef = ...,
         PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListAnomaliesForInsightResponseTypeDef]:
         """
